@@ -55,6 +55,10 @@ class DeviceType(models.Model):
     health_check_job = models.TextField(
         null=True, blank=True, default=None, validators=[validate_job_json])
 
+    use_celery = models.BooleanField(default=False,
+        help_text=("Denotes the job should be run via the celery "\
+            "schedulermonitor rather than the local one"))
+
     @models.permalink
     def get_absolute_url(self):
         return ("lava.scheduler.device_type.detail", [self.pk])
@@ -128,6 +132,9 @@ class Device(models.Model):
     def get_device_health_url(self):
         return ("lava.scheduler.labhealth.detail", [self.pk])
 
+    def use_celery(self):
+        return self.device_type.use_celery
+
     def recent_jobs(self):
         return TestJob.objects.select_related(
             "actual_device",
@@ -321,7 +328,7 @@ class TestJob(RestrictedResource):
         return ("lava.scheduler.job.detail", [self.pk])
 
     @classmethod
-    def from_json_and_user(cls, json_data, user):
+    def from_json_and_user(cls, json_data, user, health_check=False):
         job_data = simplejson.loads(json_data)
         validate_job_data(job_data)
         if 'target' in job_data:
@@ -350,9 +357,11 @@ class TestJob(RestrictedResource):
                         raise ValueError(
                             "%r is not a valid email address." % address)
 
-        job_name = job_data.get('job_name', '')
+        if job_data.get('health_check', False) and not health_check:
+            raise ValueError(
+                "cannot submit a job with health_check: true via the api.")
 
-        is_check = job_data.get('health_check', False)
+        job_name = job_data.get('job_name', '')
 
         submitter = user
         group = None
@@ -383,7 +392,7 @@ class TestJob(RestrictedResource):
         job = TestJob(
             definition=json_data, submitter=submitter,
             requested_device=target, requested_device_type=device_type,
-            description=job_name, health_check=is_check, user=user,
+            description=job_name, health_check=health_check, user=user,
             group=group, is_public=is_public)
         job.save()
         for tag in tags:
